@@ -123,10 +123,13 @@ var participleYqRules = []*participleYqRule{
 
 	simpleOp("keys", keysOpType),
 	simpleOp("key", getKeyOpType),
+	simpleOp("is_?key", isKeyOpType),
 
 	simpleOp("file_?name|fileName", getFilenameOpType),
 	simpleOp("file_?index|fileIndex|fi", getFileIndexOpType),
 	simpleOp("path", getPathOpType),
+	simpleOp("set_?path", setPathOpType),
+	simpleOp("del_?paths", delPathsOpType),
 
 	simpleOp("to_?entries|toEntries", toEntriesOpType),
 	simpleOp("from_?entries|fromEntries", fromEntriesOpType),
@@ -152,6 +155,7 @@ var participleYqRules = []*participleYqRule{
 
 	{"Uppercase", `upcase|ascii_?upcase`, opTokenWithPrefs(changeCaseOpType, nil, changeCasePrefs{ToUpperCase: true}), 0},
 	{"Downcase", `downcase|ascii_?downcase`, opTokenWithPrefs(changeCaseOpType, nil, changeCasePrefs{ToUpperCase: false}), 0},
+	simpleOp("trim", trimOpType),
 
 	{"HexValue", `0[xX][0-9A-Fa-f]+`, hexValue(), 0},
 	{"FloatValueScientific", `-?[1-9](\.\d+)?[Ee][-+]?\d+`, floatValue(), 0},
@@ -181,8 +185,8 @@ var participleYqRules = []*participleYqRule{
 	{"GreaterThan", `\s*>\s*`, opTokenWithPrefs(compareOpType, nil, compareTypePref{OrEqual: false, Greater: true}), 0},
 	{"LessThan", `\s*<\s*`, opTokenWithPrefs(compareOpType, nil, compareTypePref{OrEqual: false, Greater: false}), 0},
 
-	{"AssignRelative", `\|=`, assignOpToken(true), 0},
-	{"Assign", `=`, assignOpToken(false), 0},
+	{"AssignRelative", `\|=[c]*`, assignOpToken(true), 0},
+	{"Assign", `=[c]*`, assignOpToken(false), 0},
 
 	{`whitespace`, `[ \t\n]+`, nil, 0},
 
@@ -193,8 +197,8 @@ var participleYqRules = []*participleYqRule{
 
 	{"Union", `,`, opToken(unionOpType), 0},
 
-	{"MultiplyAssign", `\*=[\+|\?dn]*`, multiplyWithPrefs(multiplyAssignOpType), 0},
-	{"Multiply", `\*[\+|\?dn]*`, multiplyWithPrefs(multiplyOpType), 0},
+	{"MultiplyAssign", `\*=[\+|\?cdn]*`, multiplyWithPrefs(multiplyAssignOpType), 0},
+	{"Multiply", `\*[\+|\?cdn]*`, multiplyWithPrefs(multiplyOpType), 0},
 
 	{"AddAssign", `\+=`, opToken(addAssignOpType), 0},
 	{"Add", `\+`, opToken(addOpType), 0},
@@ -316,6 +320,9 @@ func assignOpToken(updateAssign bool) yqAction {
 		log.Debug("assignOpToken %v", rawToken.Value)
 		value := rawToken.Value
 		prefs := assignPreferences{DontOverWriteAnchor: true}
+		if strings.Contains(value, "c") {
+			prefs.ClobberCustomTags = true
+		}
 		op := &Operation{OperationType: assignOpType, Value: assignOpType.Type, StringValue: value, UpdateAssign: updateAssign, Preferences: prefs}
 		return &token{TokenType: operationToken, Operation: op}, nil
 	}
@@ -386,6 +393,7 @@ func envSubstWithOptions() yqAction {
 func multiplyWithPrefs(op *operationType) yqAction {
 	return func(rawToken lexer.Token) (*token, error) {
 		prefs := multiplyPreferences{}
+		prefs.AssignPrefs = assignPreferences{}
 		options := rawToken.Value
 		if strings.Contains(options, "+") {
 			prefs.AppendArrays = true
@@ -394,11 +402,14 @@ func multiplyWithPrefs(op *operationType) yqAction {
 			prefs.TraversePrefs = traversePreferences{DontAutoCreate: true}
 		}
 		if strings.Contains(options, "n") {
-			prefs.AssignPrefs = assignPreferences{OnlyWriteNull: true}
+			prefs.AssignPrefs.OnlyWriteNull = true
 		}
 		if strings.Contains(options, "d") {
 			prefs.DeepMergeArrays = true
 		}
+		if strings.Contains(options, "c") {
+			prefs.AssignPrefs.ClobberCustomTags = true
+		}
 		prefs.TraversePrefs.DontFollowAlias = true
 		op := &Operation{OperationType: op, Value: multiplyOpType.Type, StringValue: options, Preferences: prefs}
 		return &token{TokenType: operationToken, Operation: op}, nil
