@@ -6,11 +6,11 @@ func pipeOperator(d *dataTreeNavigator, context Context, expressionNode *Express
 	// BUT we still return the original context back (see jq)
 	// https://stedolan.github.io/jq/manual/#Variable/SymbolicBindingOperator:...as$identifier|...
 
-	lhs, err := d.GetMatchingNodes(context, expressionNode.Lhs)
+	lhs, err := d.GetMatchingNodes(context, expressionNode.LHS)
 	if err != nil {
 		return Context{}, err
 	}
-	rhs, err := d.GetMatchingNodes(lhs, expressionNode.Rhs)
+	rhs, err := d.GetMatchingNodes(lhs, expressionNode.RHS)
 	if err != nil {
 		return Context{}, err
 	}
